<?php
/*
Plugin Name: CF7 Redirect Settings (EasyToolsWP)
Description: Adds redirection settings to Contact Form 7
Version: 1.0
Author: EasyToolsWP.com
*/

// Add a new tab to the CF7 editor page
add_action('wpcf7_editor_panels', 'etwp_cf7_redirect_editor_panels');
function etwp_cf7_redirect_editor_panels($panels) {
    $panels['etwp-redirect-panel'] = array(
        'title' => __('Redirect Settings', 'etwp-cf7-redirect'),
        'callback' => 'etwp_cf7_redirect_editor_panel'
    );
    return $panels;
}

// Function to display the content of the new tab
function etwp_cf7_redirect_editor_panel($post) {
    $form_id = $post->id();
    $success_url = get_post_meta($form_id, '_etwp_cf7_redirect_url_success', true);
    $failure_url = get_post_meta($form_id, '_etwp_cf7_redirect_url_failure', true);
    $open_new_tab = get_post_meta($form_id, '_etwp_cf7_redirect_open_new_tab', true);

    ?>
    <div class="wpcf7-editor-panel">
        <fieldset>
            <legend><?php _e('Redirect Settings', 'etwp-cf7-redirect'); ?></legend>
            <p>
                <label for="etwp-cf7-redirect-url-success"><?php _e('Success URL', 'etwp-cf7-redirect'); ?></label>
                <input type="text" id="etwp-cf7-redirect-url-success" name="etwp-cf7-redirect-url-success" value="<?php echo esc_attr($success_url); ?>" />
            </p>
            <p>
                <label for="etwp-cf7-redirect-url-failure"><?php _e('Failure URL', 'etwp-cf7-redirect'); ?></label>
                <input type="text" id="etwp-cf7-redirect-url-failure" name="etwp-cf7-redirect-url-failure" value="<?php echo esc_attr($failure_url); ?>" />
            </p>
            <p>
                <label for="etwp-cf7-redirect-open-new-tab">
                    <input type="checkbox" id="etwp-cf7-redirect-open-new-tab" name="etwp-cf7-redirect-open-new-tab" value="1" <?php checked($open_new_tab, '1'); ?> />
                    <?php _e('Open in new tab', 'etwp-cf7-redirect'); ?>
                </label>
            </p>
        </fieldset>
    </div>
    <?php
}

// Save data from the new tab
add_action('wpcf7_save_contact_form', 'etwp_cf7_save_redirect_settings');
function etwp_cf7_save_redirect_settings($contact_form) {
    $form_id = $contact_form->id();

    if (isset($_POST['etwp-cf7-redirect-url-success'])) {
        update_post_meta($form_id, '_etwp_cf7_redirect_url_success', sanitize_text_field($_POST['etwp-cf7-redirect-url-success']));
    }

    if (isset($_POST['etwp-cf7-redirect-url-failure'])) {
        update_post_meta($form_id, '_etwp_cf7_redirect_url_failure', sanitize_text_field($_POST['etwp-cf7-redirect-url-failure']));
    }

    $open_new_tab = isset($_POST['etwp-cf7-redirect-open-new-tab']) ? '1' : '0';
    update_post_meta($form_id, '_etwp_cf7_redirect_open_new_tab', $open_new_tab);
}

// Handle redirection after form submission
add_action('wp_footer', 'etwp_cf7_redirect_after_submission');
function etwp_cf7_redirect_after_submission() {
    if (!is_singular('wpcf7_contact_form')) {
        return;
    }

    ?>
    <script type="text/javascript">
    document.addEventListener('wpcf7mailsent', function(event) {
        var formId = event.detail.contactFormId;
        var successUrl = "<?php echo esc_url(get_post_meta($formId, '_etwp_cf7_redirect_url_success', true)); ?>";
        var failureUrl = "<?php echo esc_url(get_post_meta($formId, '_etwp_cf7_redirect_url_failure', true)); ?>";
        var openInNewTab = "<?php echo get_post_meta($formId, '_etwp_cf7_redirect_open_new_tab', true); ?>";

        if (event.detail.status === 'mail_sent' && successUrl) {
            if (openInNewTab === '1') {
                window.open(successUrl, '_blank');
            } else {
                window.location.href = successUrl;
            }
        } else if (event.detail.status !== 'mail_sent' && failureUrl) {
            if (openInNewTab === '1') {
                window.open(failureUrl, '_blank');
            } else {
                window.location.href = failureUrl;
            }
        }
    }, false);
    </script>
    <?php
}

// Debug saved data
add_action('wpcf7_save_contact_form', 'etwp_cf7_debug_save_redirect_settings');
function etwp_cf7_debug_save_redirect_settings($contact_form) {
    $form_id = $contact_form->id();

    error_log('Saving settings for form ID: ' . $form_id);
    error_log('Success URL: ' . (isset($_POST['etwp-cf7-redirect-url-success']) ? sanitize_text_field($_POST['etwp-cf7-redirect-url-success']) : 'Not set'));
    error_log('Failure URL: ' . (isset($_POST['etwp-cf7-redirect-url-failure']) ? sanitize_text_field($_POST['etwp-cf7-redirect-url-failure']) : 'Not set'));
    error_log('Open in new tab: ' . (isset($_POST['etwp-cf7-redirect-open-new-tab']) ? '1' : '0'));
}
